// src/use-badge.ts
import { badge } from "@nextui-org/theme";
import { mapPropsVariants } from "@nextui-org/system";
import { useDOMRef } from "@nextui-org/dom-utils";
import { clsx } from "@nextui-org/shared-utils";
import { useMemo } from "react";
function useBadge(originalProps) {
  const [props, variantProps] = mapPropsVariants(originalProps, badge.variantKeys);
  const { as, ref, children, className, content, styles, ...otherProps } = props;
  const Component = as || "span";
  const domRef = useDOMRef(ref);
  const isOneChar = useMemo(() => {
    var _a;
    return ((_a = String(content)) == null ? void 0 : _a.length) === 1;
  }, [content]);
  const isDot = useMemo(() => {
    var _a;
    return ((_a = String(content)) == null ? void 0 : _a.length) === 0;
  }, [content]);
  const baseStyles = clsx(styles == null ? void 0 : styles.badge, className);
  const slots = useMemo(
    () => badge({
      ...variantProps,
      isOneChar,
      isDot
    }),
    [...Object.values(variantProps), isOneChar, isDot]
  );
  const getBadgeProps = () => {
    return {
      ref: domRef,
      className: slots.badge({ class: baseStyles }),
      "data-invisible": originalProps.isInvisible,
      ...otherProps
    };
  };
  return {
    Component,
    children,
    content,
    slots,
    styles,
    getBadgeProps
  };
}

export {
  useBadge
};
