import * as tailwind_variants from 'tailwind-variants';
import * as _nextui_org_system from '@nextui-org/system';
import { HTMLNextUIProps, PropGetter } from '@nextui-org/system';
import { BadgeVariantProps, SlotsToClasses, BadgeSlots } from '@nextui-org/theme';
import { ReactNode } from 'react';
import { ReactRef } from '@nextui-org/shared-utils';

interface UseBadgeProps extends HTMLNextUIProps<"span">, BadgeVariantProps {
    /**
     * Ref to the DOM node.
     */
    ref?: ReactRef<HTMLDivElement | null>;
    /**
     * The children of the badge.
     */
    children: ReactNode;
    /**
     * The content of the badge. The badge will be rendered relative to its children.
     */
    content?: string | number | ReactNode;
    /**
     * Classname or List of classes to change the styles of the element.
     * if `className` is passed, it will be added to the base slot.
     *
     * @example
     * ```ts
     * <Badge styles={{
     *    base:"base-classes", // wrapper
     *    badge: "badge-classes",
     * }} />
     * ```
     */
    styles?: SlotsToClasses<BadgeSlots>;
}
declare function useBadge(originalProps: UseBadgeProps): {
    Component: _nextui_org_system.As<any>;
    children: ReactNode;
    content: ReactNode;
    slots: {
        base: (slotProps?: tailwind_variants.ClassProp<tailwind_variants.ClassValue> | undefined) => string;
        badge: (slotProps?: tailwind_variants.ClassProp<tailwind_variants.ClassValue> | undefined) => string;
    };
    styles: SlotsToClasses<"base" | "badge"> | undefined;
    getBadgeProps: PropGetter<Record<string, unknown>, _nextui_org_system.DOMAttributes<_nextui_org_system.DOMElement>>;
};
type UseBadgeReturn = ReturnType<typeof useBadge>;

export { UseBadgeProps, UseBadgeReturn, useBadge };
